summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJon Mayo <jmayo@nvidia.com>2011-08-26 15:04:00 -0700
committerVarun Colbert <vcolbert@nvidia.com>2011-08-29 19:12:34 -0700
commit3ba3ab1cf6e1692f46b26a17e8b8a99ecd010d6c (patch)
tree014a3716189c6e2f58bb807868d9f8437495f53b
parent03f5a82c2f5b19507540cc9ea47e3ea3832c69e2 (diff)
video: tegra: dc: errdiff dithering limited to 1280
the errdiff dithering mode is limited to 1280 pixels per line. There was some confusion and 640 was used in code and documentation. Bug 803059 Change-Id: Ia802cc5bca72cf55621487f18369278be254de72 Reviewed-on: http://git-master/r/49538 Reviewed-by: Varun Colbert <vcolbert@nvidia.com> Tested-by: Varun Colbert <vcolbert@nvidia.com>
-rw-r--r--drivers/video/tegra/dc/dc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/video/tegra/dc/dc.c b/drivers/video/tegra/dc/dc.c
index 1884f361cdf7..2bf4e1b77bb1 100644
--- a/drivers/video/tegra/dc/dc.c
+++ b/drivers/video/tegra/dc/dc.c
@@ -2046,11 +2046,11 @@ static void tegra_dc_set_color_control(struct tegra_dc *dc)
break;
case TEGRA_DC_ERRDIFF_DITHER:
/* The line buffer for error-diffusion dither is limited
* to 640 pixels per line. This limits the maximum
* horizontal active area size to 640 pixels when error
* diffusion is enabled.
*/
- BUG_ON(dc->mode.h_active > 640);
+ BUG_ON(dc->mode.h_active > 1280);
color_control |= DITHER_CONTROL_ERRDIFF;
break;
}
@@ -2046,11 +2046,11 @@ static void tegra_dc_set_color_control(struct tegra_dc *dc)
case TEGRA_DC_ERRDIFF_DITHER:
/* The line buffer for error-diffusion dither is limited
- * to 640 pixels per line. This limits the maximum
- * horizontal active area size to 640 pixels when error
+ * to 1280 pixels per line. This limits the maximum
+ * horizontal active area size to 1280 pixels when error
* diffusion is enabled.
*/